==> igniteui-webcomponents-layouts-4.8.1.tgz: package/esm5/lib/igc-tool-action-radio-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionRadio } from "./ToolActionRadio";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionRadioComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionRadioComponent, _super);
    function IgcToolActionRadioComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionRadioComponent.prototype.createImplementation = function () {
        return new ToolActionRadio();
    };
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionRadioComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionRadioComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionRadioComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent == null) {
                var names = getAllPropertyNames(IgcToolActionRadioComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = names;
            }
            return IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionRadioComponent.register = function () {
        if (!IgcToolActionRadioComponent._isElementRegistered) {
            IgcToolActionRadioComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionRadioComponent.htmlTagName, IgcToolActionRadioComponent);
        }
    };
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "channel", {
        /**
         * Gets or sets the channel this radio button belongs to.
        */
        get: function () {
            return this.i.gg;
        },
        set: function (v) {
            this.i.gg = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "isChecked", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.f9;
        },
        set: function (v) {
            this.i.f9 = ensureBool(v);
            this._a("isChecked", this.i.f9);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "isManual", {
        /**
         * Gets or sets if the checked state of the radio is handled manually by the user. The radio
         * well not become selected when clicked if this property is true.
        */
        get: function () {
            return this.i.ga;
        },
        set: function (v) {
            this.i.ga = ensureBool(v);
            this._a("isManual", this.i.ga);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.g4);
        },
        set: function (v) {
            this.i.g4 = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.g4));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualUncheckedBackgroundColor", {
        /**
         * Gets the actual background color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.g0);
        },
        set: function (v) {
            this.i.g0 = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.g0));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.g2);
        },
        set: function (v) {
            this.i.g2 = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.g2));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualCheckedBackgroundColor", {
        /**
         * Gets the actual background color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gy);
        },
        set: function (v) {
            this.i.gy = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.gy));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.g5);
        },
        set: function (v) {
            this.i.g5 = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.g5));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualUncheckedBorderColor", {
        /**
         * Gets the actual border color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.g1);
        },
        set: function (v) {
            this.i.g1 = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.g1));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.g3);
        },
        set: function (v) {
            this.i.g3 = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.g3));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualCheckedBorderColor", {
        /**
         * Gets the actual border color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gz);
        },
        set: function (v) {
            this.i.gz = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.gz));
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionRadioComponent.prototype.fromInfo = function (info) {
        this.i.ej(info);
    };
    IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = null;
    IgcToolActionRadioComponent.htmlTagName = "igc-tool-action-radio";
    IgcToolActionRadioComponent._isElementRegistered = false;
    return IgcToolActionRadioComponent;
}(IgcToolActionComponent));
export { IgcToolActionRadioComponent };

==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm5/lib/igc-tool-action-radio-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionRadio } from "./ToolActionRadio";
import { getAllPropertyNames, toSpinal, ensureBool, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionRadioComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionRadioComponent, _super);
    function IgcToolActionRadioComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionRadioComponent.prototype.createImplementation = function () {
        return new ToolActionRadio();
    };
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionRadioComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionRadioComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionRadioComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent == null) {
                var names = getAllPropertyNames(IgcToolActionRadioComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = names;
            }
            return IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionRadioComponent.register = function () {
        if (!IgcToolActionRadioComponent._isElementRegistered) {
            IgcToolActionRadioComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionRadioComponent.htmlTagName, IgcToolActionRadioComponent);
        }
    };
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "channel", {
        /**
         * Gets or sets the channel this radio button belongs to.
        */
        get: function () {
            return this.i.hk;
        },
        set: function (v) {
            this.i.hk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "isChecked", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.hd;
        },
        set: function (v) {
            this.i.hd = ensureBool(v);
            this._a("isChecked", this.i.hd);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "isManual", {
        /**
         * Gets or sets if the checked state of the radio is handled manually by the user. The radio
         * well not become selected when clicked if this property is true.
        */
        get: function () {
            return this.i.he;
        },
        set: function (v) {
            this.i.he = ensureBool(v);
            this._a("isManual", this.i.he);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h8);
        },
        set: function (v) {
            this.i.h8 = stringToBrush(v);
            this._a("uncheckedBackgroundColor", brushToString(this.i.h8));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualUncheckedBackgroundColor", {
        /**
         * Gets the actual background color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h4);
        },
        set: function (v) {
            this.i.h4 = stringToBrush(v);
            this._a("actualUncheckedBackgroundColor", brushToString(this.i.h4));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.h6);
        },
        set: function (v) {
            this.i.h6 = stringToBrush(v);
            this._a("checkedBackgroundColor", brushToString(this.i.h6));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualCheckedBackgroundColor", {
        /**
         * Gets the actual background color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.h2);
        },
        set: function (v) {
            this.i.h2 = stringToBrush(v);
            this._a("actualCheckedBackgroundColor", brushToString(this.i.h2));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h9);
        },
        set: function (v) {
            this.i.h9 = stringToBrush(v);
            this._a("uncheckedBorderColor", brushToString(this.i.h9));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualUncheckedBorderColor", {
        /**
         * Gets the actual border color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h5);
        },
        set: function (v) {
            this.i.h5 = stringToBrush(v);
            this._a("actualUncheckedBorderColor", brushToString(this.i.h5));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.h7);
        },
        set: function (v) {
            this.i.h7 = stringToBrush(v);
            this._a("checkedBorderColor", brushToString(this.i.h7));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionRadioComponent.prototype, "actualCheckedBorderColor", {
        /**
         * Gets the actual border color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.h3);
        },
        set: function (v) {
            this.i.h3 = stringToBrush(v);
            this._a("actualCheckedBorderColor", brushToString(this.i.h3));
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionRadioComponent._observedAttributesIgcToolActionRadioComponent = null;
    IgcToolActionRadioComponent.htmlTagName = "igc-tool-action-radio";
    IgcToolActionRadioComponent._isElementRegistered = false;
    return IgcToolActionRadioComponent;
}(IgcToolActionComponent));
export { IgcToolActionRadioComponent };
